<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="500px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="150px" >
        <el-form-item label="姓名:" prop="personName" >
          <el-input v-model="state.form.personName" placeholder="请输入姓名"></el-input>
        </el-form-item>
        <el-form-item label="人员类型:"  prop="personType">
          <el-select
              v-model="state.form.personType"
              placeholder="请选择"
              style="width: 100%"
          >
            <el-option
                v-for="item in state.typeList"
                :key="item.id"
                :label="item.name"
                :value="item.id"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="联系方式:" prop="mb" >
          <el-input v-model="state.form.mb" placeholder="请输入联系方式"></el-input>
        </el-form-item>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {onMounted, reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";
import {listDept} from "@/api/system/dept";
import {listUser} from "@/api/system/user";
import {addTemplate, editTemplate} from "@/api/signAgreement/template";
import {addType, editType, getSignType} from "@/api/signAgreement/signType";
import {getInfo} from "@/api/login";
import {getToken} from "@/utils/auth";
import {verifyPhone} from "@/utils/validate";
import Cookies from "js-cookie";
import {addPeople} from "@/api/company/people";

const uploadFileUrl = ref(import.meta.env.VITE_APP_BASE_API + "/common/upload"); // 上传文件服务器地址
const { proxy } = getCurrentInstance();
const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const startPhone = ref('');
const validateUserPhone = (rule, value, callback)=>{
  if(value === ''){
    callback(new Error('请输入手机号'))
  }else if(state.title == '编辑' && value == startPhone.value){
    callback()
  } else{
    if(!verifyPhone(value)){
      callback(new Error('手机号格式有误'))
    }else{
      callback()
    }
  }
}
const state = reactive({
  form: {
    id: '',
    personName: '',
    companyCode: '',
    personType:null,
    mb: '',
  },
  typeList: [
    {
      id: 1,
      name: '法定代表人'
    },
    {
      id: 2,
      name: '主要负责人'
    },
    {
      id: 3,
      name: '安全负责人'
    },
    {
      id: 4,
      name: '保管员'
    },
    {
      id: 5,
      name: '守护员'
    },
  ],
  formRules:{
    personName: [{ required: true, trigger: "blur", message:'请输入姓名' }],
    mb: [{ required: true, trigger: "blur", validator: validateUserPhone }],
    personType: [{ required: true, trigger: "blur", message:'请选择人员类型' }],
  },
})
onMounted(()=>{

})


const openDialog = async (type,value) => {
  title.value = type === 'add' ? '新增' : '编辑'
  const info = JSON.parse(Cookies.get('userInfo'))
  state.form.companyCode = info.companynumber
  if(type === 'edit') {
    const data = JSON.parse(JSON.stringify(value))
    Object.keys(state.form).forEach(key => {
      if(data[key]){
        state.form[key] = data[key]
      }
    })
    startPhone.value = value.phone
  }
  dialogVisible.value = true;
}

const onSubmit = async () => {
  console.log('form',state.form)
  const valid = await busRef.value.validate();
  if(valid){
    if(title.value === '新增'){
      const {id, ...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addPeople(data)
      if(res.code == 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '编辑'){
      const {...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addPeople(data)
      if(res.code == 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }

  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")
}
const reset = () => {
  state.form = {
    id: '',
    personName: '',
    companyCode: '',
    personType:null,
    mb: '',
  }
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  :deep(.el-form-item__content) {
    width: 100%;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
  .custom-iframe {
    border: 1px solid #9b9999;
    /* 隐藏原生滚动条 */
    overflow: hidden;
  }
}
</style>
